@@ -3,6 +3,7 @@ import argparse
 import os
 
 from lmpy.data_preparation.layer_encoder import LayerEncoder
+from lmpy.tools._config_parser import _process_arguments
 
 
 DESCRIPTION = 'Encode raster and / or vector layers into a site by layer matrix.'
@@ -17,6 +18,7 @@ def cli():
             arguments.
     """
     parser = argparse.ArgumentParser(description=DESCRIPTION)
+    parser.add_argument('--config_file', type=str, help='Path to configuration file.')
     parser.add_argument(
         '--encode_method',
         '-m',
@@ -62,7 +64,7 @@ def cli():
         help='File location of layer [ LABEL [ EVENT FIELD ]].',
     )
 
-    args = parser.parse_args()
+    args = _process_arguments(parser, config_arg='config_file')
 
     encoder = LayerEncoder(args.shapegrid_filename)
 
